@@ -14,8 +14,12 @@ tasks <- function(iss, desktop_icon = TRUE) {
   }
 
   if (as.logical(desktop_icon)) {
-  iss <- c(iss, "\n[Tasks]",
-    'Name: "desktopicon"; Description: "{cm:CreateDesktopIcon}"')
+    iss <- glue::glue('
+                    {iss}
+
+                    [Tasks]
+                    Name: "desktopicon"; Description: "{{cm:CreateDesktopIcon}}"
+                    ')
   }
 
   iss
